@@ -1,5 +1,4 @@
 """Test extension syntax."""
-from __future__ import unicode_literals
 import os
 import markdown
 import difflib
@@ -38,7 +37,7 @@ def set_target_file(file_name):
 
 
 def compare_results(cfg, testfile, update=False):
-    """Compare test reslts."""
+    """Compare test results."""
 
     extension = []
     extension_config = {}
@@ -101,7 +100,7 @@ def gather_test_params():
         cfg_path = os.path.join(base, 'tests.yml')
         if os.path.exists(cfg_path):
             files.remove('tests.yml')
-            [files.remove(file) for file in files if not file.endswith('.txt')]
+            [files.remove(file) for file in files[:] if not file.endswith('.txt')]
             with codecs.open(cfg_path, 'r', encoding='utf-8') as f:
                 cfg = util.yaml_load(f.read())
             for testfile in files:
@@ -119,12 +118,19 @@ def gather_test_params():
                     for k1, v1 in v.items():
                         if v1 is not None:
                             for k2, v2 in v1.items():
-                                if isinstance(v2, util.string_type):
+                                if isinstance(v2, str):
                                     v1[k2] = v2.replace(
                                         '{{BASE}}', base
                                     ).replace(
                                         '{{RELATIVE}}', CURRENT_DIR
                                     )
+                                elif k2 == 'base_path' and isinstance(v2, list):
+                                    for i, v3 in enumerate(v2, 0):
+                                        v1[k2][i] = v3.replace(
+                                            '{{BASE}}', base
+                                        ).replace(
+                                            '{{RELATIVE}}', CURRENT_DIR
+                                        )
                         test_cfg[k][k1] = v1
                 target = os.path.join(base, testfile)
                 if target_file is not None and target != target_file:
@@ -135,7 +141,7 @@ def gather_test_params():
 def pytest_generate_tests(metafunc):
     """Generate tests."""
 
-    if "compare" in metafunc.funcargnames:
+    if "compare" in metafunc.fixturenames:
         metafunc.parametrize("compare", gather_test_params())
 
 
